# Changelog

<!-- This file should be auto-generated using the auto-changelog command (https://www.npmjs.com/package/auto-changelog) -->

## 0.1.0.dev0

> 22 October 2024

### New Features

- Example code in Python


### Fixes

- Describe Bug Fixes here
- Remove this subsection if there are no Bug Fixes


### Performance improvements

- Describe Improvements here
- Remove this subsection if there are no Improvements
